identity_updates

Function identity_updates 

pub fn identity_updates() -> Option<IdentityUpdates>
Take the identity-update receiver.

Cancellation-safe to await. None only if one was already taken, which would mean two things writing the same profile fields.