pub fn mac_counters() -> MacCountersExpand description
The most recently published MAC tallies.
All zero before the node’s first wake cycle, which is indistinguishable from a node that has done nothing — and is the same thing as far as a reader is concerned.