pub type SharedFlash<M, F> = Mutex<M, F>;
One flash driver shared between every journal on the board, behind the async mutex that serializes access to it.
pub struct SharedFlash<M, F> { /* private fields */ }