radio_mux

Function radio_mux 

pub async fn radio_mux<M, const RX: usize, const TX: usize>(
    real: &'static Channels<M, RX, TX>,
    clients: &'static [&'static Channels<M, RX, TX>],
) -> !
where M: RawMutex,
Run the multiplexer over the real radio Channels bundle.

real must be the bundle served by the radio runner, and the mux must be that bundle’s only client. Each entry in clients is one virtual bundle, owned (RX-drained and TX-fed) by exactly one radio client.